@@ -1,6 +1,5 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-import _envi
 CACHE_DICT = {}
 
 class InterCache(object):
@@ -19,6 +18,8 @@ class InterCache(object):
             result[i] = self.get(i)
         return result
 
+    get_multi = get_list
+
     def set(self, k, v):
         self.cache[k] = v
 
@@ -28,7 +29,7 @@ class InterCache(object):
         except KeyError:
             pass
 
-cache = InterCache(CACHE_DICT)
+mc = InterCache(CACHE_DICT)
 
         
 if __name__ == '__main__':
